pub struct FunctionOption {
pub name: String,
pub preference: Vec<String>,
}Expand description
A named, optional behavioral preference for a function call. Options allow producers to express preferences about how consumers handle corner cases or engine-specific behavior (e.g. overflow or rounding mode). Unlike function arguments, options are not required. If omitted, the consumer is free to choose any supported behavior.
Fields
name: StringName of the option to set. If the consumer does not recognize the option, it must reject the plan. The name is matched case-insensitively with option names defined for the function.
preference: Vec<String>List of behavior options allowed by the producer. At least one must be
specified; to leave an option unspecified, simply don’t add an entry to
options. The consumer must use the first option from the list that it
supports. If the consumer supports none of the specified options, it
must reject the plan. The name is matched case-insensitively and must
match one of the option values defined for the option.